"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createState = createState;
exports.getState = getState;

var _crypto = require("crypto");

/**
 * Returns state if provider supports it
 * @param {import("src/types/internals").NextAuthRequest} req
 * @param {import("src/types/internals").NextAuthResponse} res
 */
function createState(req) {
  var _provider$checks;

  const {
    csrfToken,
    logger
  } = req.options;
  /** @type {import("src/providers").OAuthConfig} */

  const provider = req.options.provider;

  if (!((_provider$checks = provider.checks) !== null && _provider$checks !== void 0 && _provider$checks.includes("state"))) {
    // Provider does not support state, return nothing
    return;
  } // A hash of the NextAuth.js CSRF token is used as the state


  const state = (0, _crypto.createHash)("sha256").update(csrfToken).digest("hex");
  logger.debug("OAUTH_CALLBACK_PROTECTION", {
    state,
    csrfToken
  });
  return state;
}
/**
 * Consistently recreate state from the csrfToken
 * if `provider.checks` supports `"state"`.
 * @param {import("src/types/internals").NextAuthRequest} req
 */


function getState({
  options
}) {
  /** @type {import("src/providers").OAuthConfig} */
  const provider = options.provider;

  if (provider !== null && provider !== void 0 && provider.checks.includes("state")) {
    return (0, _crypto.createHash)("sha256").update(options.csrfToken).digest("hex");
  }
}