"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = parseProviders;

var _merge = require("../../lib/merge");

/**
 * Adds `signinUrl` and `callbackUrl` to each provider
 * and deep merge user-defined options.
 * @param {{
 *  providers: import("src/providers").Provider[]
 *  baseUrl: string
 *  basePath: string
 * }} options
 * @returns {import("src/types/internals").InternalOptions["providers"]}
 */
function parseProviders({
  providers = [],
  baseUrl,
  basePath
}) {
  const base = `${baseUrl}${basePath}`;
  return providers.map(({
    options,
    ...defaultOptions
  }) => (0, _merge.merge)(defaultOptions, {
    signinUrl: `${base}/signin/${defaultOptions.id}`,
    callbackUrl: `${base}/callback/${defaultOptions.id}`,
    ...options
  }));
}