"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fromDate = fromDate;
exports.hashToken = hashToken;
exports.default = createSecret;

var _crypto = require("crypto");

/**
 * Takes a number in seconds and returns the date in the future.
 * Optionally takes a second date parameter. In that case
 * the date in the future will be calculated from that date instead of now.
 */
function fromDate(time, date = Date.now()) {
  return new Date(date + time * 1000);
}

function hashToken(token, options) {
  var _provider$secret;

  const {
    provider,
    secret
  } = options;
  return (0, _crypto.createHash)("sha256") // Prefer provider specific secret, but use default secret if none specified
  .update(`${token}${(_provider$secret = provider.secret) !== null && _provider$secret !== void 0 ? _provider$secret : secret}`).digest("hex");
}
/**
 * Secret used salt cookies and tokens (e.g. for CSRF protection).
 * If no secret option is specified then it creates one on the fly
 * based on options passed here. A options contains unique data, such as
 * OAuth provider secrets and database credentials it should be sufficent.
 */


function createSecret({
  userOptions,
  basePath,
  baseUrl
}) {
  var _userOptions$secret;

  return (_userOptions$secret = userOptions.secret) !== null && _userOptions$secret !== void 0 ? _userOptions$secret : (0, _crypto.createHash)("sha256").update(JSON.stringify({
    baseUrl,
    basePath,
    ...userOptions
  })).digest("hex");
}